# BV4115W - wifi connected relay class
# Use
# import BV4115W
# s = BV4115W.bv4115('ip address',port)
# s.wfCheck() # should return true
# s.wfCmd('ip')
# s.devCmd('dD') returns device id
#
import socket


class bv4115():
	# **************************************************************************
	# connects to given ip and port
	# **************************************************************************
	def __init__(self, HOST, PORT):
		print 'Connnecting to {} Port {}'.format(HOST,PORT)
		try:
			self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
			self.s.connect((HOST, PORT)) # remote reports Link here
			self.s.send('\r') # clear connect message
			self.s.settimeout(5) # 5 seconds
		except:
			print 'No connection could be made'
			self.s = None

	# **************************************************************************
	# wfread will return when 1 char has been recieved
	# looks for *A as ack
	# **************************************************************************
	def wfRead(self):
		ack=0
		rv = ''
		while True:
			try:
				data = self.s.recv(1)
				if (ack == 1) and ((data == 'A') or (data == 'N')):
					return rv
				else:
					if (ack==0) and (data == '*'):
						ack = 1
					else:
						rv = rv + data
			except:
				return rv

	# **************************************************************************
	# devRead will return when ACK or NACK
	# **************************************************************************
	def devRead(self):
		rv = ''
		while True:
			try:
				data = self.s.recv(1)
				if (data == '\x06') or (data == '\x015'):
					return rv
				else:
					rv = rv + data
			except:
				return rv

	# **************************************************************************
	# closes socket
	# **************************************************************************
	def close(self):
		self.s.close()

	# **************************************************************************
	# sends a command to the wi-fi link, just use actual command name like
	# 'hello' or 'info'
	# **************************************************************************
	def wfCmd(self,c):
		self.s.send('\r\n+++'+c+'\n\r')
		return self.wfRead()

	# **************************************************************************
	# sends a command to a device and returns the result. adds the '\r', requires
	# address
	# **************************************************************************
	def devCmd(self,c):
		self.s.send(c+'\r')
		return self.devRead()

	# **************************************************************************
	# checks that it is connectedto a sender device, by checking
	# for ACK, in the hello command
	# **************************************************************************
	def wfCheck(self):
		# only if connected
		if self.s == None:
			return False
		# checks connected to a sender device
  		self.s.send('\r\n+++hello\n\r')
		x = self.s.recv(1)
		self.s.recv(1) # dump 'A'
		if x == '*':
			return True
		else:
			return False



